@@ -7,10 +7,10 @@
  * it under the terms of the GNU General Public License
  * (GPL, see LICENSE file for details) and the provision that
  * this notice remains intact. If you modify this file, please
- * note section 2a) of the GPLv2 states that:
+ * note section 5a) of the GPLv3 states that:
  *
- *  a) You must cause the modified files to carry prominent notices
- *     stating that you changed the files and the date of any change.
+ *  a) The work must carry prominent notices stating that you modified
+ *  it, and giving a relevant date.
  *
  * This software is distributed "AS IS", with ABSOLUTELY NO WARRANTY.
  * See the GPL for specific language governing rights and limitations.
@@ -378,7 +378,8 @@ void cpggray(const float *a, int idim, int jdim, int i1, int i2, \
 {
   float affine[6];
   convert_tr_to_affine(tr,affine);
-  giza_render_gray_float(idim,jdim,a,i1-1,i2-1,j1-1,j2-1,fg,bg,GIZA_EXTEND_NONE,affine);
+  giza_render_gray_float(idim,jdim,a,i1-1,i2-1,j1-1,j2-1,fg,bg, \
+                         GIZA_EXTEND_NONE,GIZA_FILTER_NEAREST,affine);
 }
 
 /***************************************************************
@@ -420,7 +421,8 @@ void cpgimag(const float *a, int idim, int jdim, int i1, int i2, \
 {
   float affine[6];
   convert_tr_to_affine(tr,affine);
-  giza_render_float(idim,jdim,a,i1-1,i2-1,j1-1,j2-1,a1,a2,GIZA_EXTEND_NONE,affine);
+  giza_render_float(idim,jdim,a,i1-1,i2-1,j1-1,j2-1,a1,a2, \
+                    GIZA_EXTEND_NONE,GIZA_FILTER_NEAREST,affine);
 }
 
 /***************************************************************
@@ -568,7 +570,8 @@ void cpgpap(float width, float aspect)
 void cpgpixl(const int *ia, int idim, int jdim, int i1, int i2, \
  int j1, int j2, float x1, float x2, float y1, float y2)
 {
-  giza_draw_pixels_float(idim,jdim,ia,i1-1,i2-1,j1-1,j2-1,x1,x2,y1,y2,GIZA_EXTEND_NONE);
+  giza_draw_pixels_float(idim,jdim,ia,i1-1,i2-1,j1-1,j2-1,x1,x2,y1,y2,\
+                         GIZA_EXTEND_NONE,GIZA_FILTER_NEAREST);
 }
 
 /***************************************************************
@@ -798,7 +801,7 @@ void cpgqinf(const char *item, char *value, int *value_length)
  ***************************************************************/
 void cpgqitf(int *itf)
 {
-	giza_get_image_transfer_function(itf);
+       giza_get_image_transfer_function(itf);
 }
 
 /***************************************************************
@@ -1069,7 +1072,7 @@ void cpgshs(float angle, float sepn, float phase)
  ***************************************************************/
 void cpgsitf(int itf)
 {
-	giza_set_image_transfer_function(itf);
+       giza_set_image_transfer_function(itf);
 }
 
 /***************************************************************
