@@ -8,10 +8,10 @@
 !  it under the terms of the GNU General Public License
 !  (GPL, see LICENSE file for details) and the provision that
 !   this notice remains intact. If you modify this file, please
-!  note section 2a) of the GPLv2 states that:
+!   note section 5a) of the GPLv3 states that:
 !
-!   a) You must cause the modified files to carry prominent notices
-!      stating that you changed the files and the date of any change.
+!    a) The work must carry prominent notices stating that you modified
+!    it, and giving a relevant date.
 !
 !  This software is distributed "AS IS", with ABSOLUTELY NO WARRANTY.
 !  See the GPL for specific language governing rights and limitations.
@@ -263,7 +263,7 @@ subroutine PGCONB (A, IDIM, JDIM, I1, I2, J1, J2, C, NC, TR, BLANK)
  real                :: affine(6)
 
  call convert_tr_to_affine(tr,affine)
- call giza_contour(idim,jdim,a,i1-1,i2-1,j1-1,j2-1,abs(nc),C,affine)
+ call giza_contour(idim,jdim,a,i1-1,i2-1,j1-1,j2-1,nc,C,affine)
 
 end subroutine PGCONB
 
@@ -563,7 +563,7 @@ end subroutine PGFUNY
 ! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 subroutine PGGRAY (A, IDIM, JDIM, I1, I2, J1, J2, FG, BG, TR)
- use giza,       only:giza_render_gray,giza_extend_none
+ use giza,       only:giza_render_gray,giza_extend_none,giza_filter_nearest
  use gizapgplot, only:convert_tr_to_affine
  implicit none
  integer, intent(in) :: IDIM, JDIM, I1, I2, J1, J2
@@ -571,7 +571,7 @@ subroutine PGGRAY (A, IDIM, JDIM, I1, I2, J1, J2, FG, BG, TR)
  real, dimension(6)  :: affine
 
  call convert_tr_to_affine(tr,affine)
- call giza_render_gray(idim,jdim,a,i1-1,i2-1,j1-1,j2-1,fg,bg,giza_extend_none,affine)
+ call giza_render_gray(idim,jdim,a,i1-1,i2-1,j1-1,j2-1,fg,bg,giza_extend_none,giza_filter_nearest,affine)
 
 end subroutine PGGRAY
 
@@ -623,7 +623,7 @@ end subroutine PGIDEN
 ! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 subroutine PGIMAG (A, IDIM, JDIM, I1, I2, J1, J2, A1, A2, TR)
- use giza,       only:giza_render,giza_extend_none
+ use giza,       only:giza_render,giza_extend_none,giza_filter_nearest
  use gizapgplot, only:convert_tr_to_affine
  implicit none
  integer, intent(in) :: IDIM, JDIM, I1, I2, J1, J2
@@ -631,7 +631,7 @@ subroutine PGIMAG (A, IDIM, JDIM, I1, I2, J1, J2, A1, A2, TR)
  real                :: affine(6)
 
  call convert_tr_to_affine(tr,affine)
- call giza_render(idim,jdim,a,i1-1,i2-1,j1-1,j2-1,a1,a2,giza_extend_none,affine)
+ call giza_render(idim,jdim,a,i1-1,i2-1,j1-1,j2-1,a1,a2,giza_extend_none,giza_filter_nearest,affine)
 
 end subroutine PGIMAG
 
@@ -687,7 +687,7 @@ subroutine PGLEN (UNITS, STRING, XL, YL)
  integer,       intent(in) :: UNITS
  character*(*), intent(in) :: STRING
 
- call giza_qtextlen(units_giza(UNITS),STRING,XL,YL)
+ call giza_qtextlen(units_giza(UNITS),trim(STRING),XL,YL)
 
 end subroutine PGLEN
 
@@ -728,7 +728,7 @@ subroutine PGMTXT (SIDE, DISP, COORD, FJUST, TEXT)
  character*(*), intent(in) :: SIDE, TEXT
  real, intent(in) :: DISP, COORD, FJUST
 
- call giza_annotate(SIDE,DISP,COORD,FJUST,TEXT)
+ call giza_annotate(SIDE,DISP,COORD,FJUST,TEXT(:LEN_TRIM(TEXT)))
 
 end subroutine PGMTXT
 
@@ -841,14 +841,14 @@ end subroutine PGPAP
 ! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 subroutine PGPIXL (IA, IDIM, JDIM, I1, I2, J1, J2, X1, X2, Y1, Y2)
- use giza, only:giza_draw_pixels,giza_extend_none
+ use giza, only:giza_draw_pixels,giza_extend_none,giza_filter_nearest
  implicit none
  integer, intent(in) :: IDIM, JDIM, I1, I2, J1, J2
  integer, intent(in) :: IA(IDIM,JDIM)
  real,    intent(in) :: X1, X2, Y1, Y2
 
  call giza_draw_pixels(IDIM, JDIM, IA, I1-1, I2-1, J1-1, J2-1, X1, X2, Y1, Y2,&
-                       giza_extend_none)
+                       giza_extend_none,giza_filter_nearest)
 
 end subroutine PGPIXL
 
@@ -917,7 +917,7 @@ subroutine PGPTXT (X, Y, ANGLE, FJUST, TEXT)
  real,          intent(in) :: X, Y, ANGLE, FJUST
  character*(*), intent(in) :: TEXT
 
- call giza_ptext(X, Y, ANGLE, FJUST, TEXT)
+ call giza_ptext(X, Y, ANGLE, FJUST, TEXT(:LEN_TRIM(TEXT)))
 
 end subroutine PGPTXT
 
@@ -1240,7 +1240,7 @@ subroutine PGQTXT (X, Y, ANGLE, FJUST, TEXT, XBOX, YBOX)
  character*(*), intent(in) :: TEXT
  real, intent(out) :: XBOX(4), YBOX(4)
 
- call giza_qtext(X, Y, ANGLE, FJUST, TEXT, XBOX, YBOX)
+ call giza_qtext(X, Y, ANGLE, FJUST, TEXT(:LEN_TRIM(TEXT)), XBOX, YBOX)
 
 end subroutine PGQTXT
 
@@ -1675,7 +1675,7 @@ subroutine PGTEXT (X, Y, TEXT)
  real,          intent(in) :: X, Y
  character*(*), intent(in) :: TEXT
 
- call giza_text(X, Y, TEXT)
+ call giza_text(X, Y, TEXT(:LEN_TRIM(TEXT)))
 
 end subroutine PGTEXT
 
