@@ -7,10 +7,10 @@
  * it under the terms of the GNU General Public License
  * (GPL, see LICENSE file for details) and the provision that
  * this notice remains intact. If you modify this file, please
- * note section 2a) of the GPLv2 states that:
+ * note section 5a) of the GPLv3 states that:
  *
- *  a) You must cause the modified files to carry prominent notices
- *     stating that you changed the files and the date of any change.
+ *  a) The work must carry prominent notices stating that you modified
+ *  it, and giving a relevant date.
  *
  * This software is distributed "AS IS", with ABSOLUTELY NO WARRANTY.
  * See the GPL for specific language governing rights and limitations.
@@ -49,6 +49,7 @@
  *  -valMax        :- The value in data that gets assigned the colour corresponding to one
  *                    on the colour ramp
  *  -extend        :- Option for how to deal with image at edges
+ *  -filter        :- Option for how to interpolate between pixels (since v1.5)
  *  -affine        :- The affine transformation matrix that will be applied to the data.
  *
  * Allowed extend settings:
@@ -57,13 +58,21 @@
  *  -2 or GIZA_EXTEND_REFLECT :- reflective boundary
  *  -3 or GIZA_EXTEND_PAD     :- pad by extending last few pixels
  *
+ * Allowed filter settings (from cairo_filter_t):
+ *  -0 or GIZA_FILTER_DEFAULT  :- default, usually bilinear interpolation
+ *  -1 or GIZA_FILTER_FAST     :- a high performance filter with quality similar to GIZA_FILTER_NEAREST
+ *  -2 or GIZA_FILTER_GOOD     :- a reasonable-performance filter, with quality similar to GIZA_FILTER_BILINEAR
+ *  -3 or GIZA_FILTER_BEST     :- highest quality available, performance may not be suited for interactive use
+ *  -4 or GIZA_FILTER_NEAREST  :- Nearest-neighbour filtering
+ *  -5 or GIZA_FILTER_BILINEAR :- Linear interpolation in two dimensions
+ *
  * See Also: giza_set_colour_table
  */
 void
 giza_render (int sizex, int sizey, const double* data, int i1, int i2,
-             int j1, int j2, double valMin, double valMax, int extend, const double *affine)
+             int j1, int j2, double valMin, double valMax, int extend, int filter, const double *affine)
 {
-   _giza_render (sizex, sizey, data,i1,i2,j1,j2,valMin,valMax,affine,0,extend,data);
+   _giza_render (sizex, sizey, data,i1,i2,j1,j2,valMin,valMax,affine,0,extend,filter,data);
 }
 
 /**
@@ -74,9 +83,9 @@ giza_render (int sizex, int sizey, const double* data, int i1, int i2,
  */
 void
 giza_render_transparent (int sizex, int sizey, const double* data, int i1, int i2,
-	    int j1, int j2, double valMin, double valMax, int extend, const double *affine)
+           int j1, int j2, double valMin, double valMax, int extend, int filter, const double *affine)
 {
-   _giza_render (sizex, sizey, data,i1,i2,j1,j2,valMin,valMax,affine,1,extend,data);
+   _giza_render (sizex, sizey, data,i1,i2,j1,j2,valMin,valMax,affine,1,extend,filter,data);
 }
 
 /**
@@ -87,9 +96,9 @@ giza_render_transparent (int sizex, int sizey, const double* data, int i1, int i
  */
 void
 giza_render_alpha (int sizex, int sizey, const double* data, const double* alpha, int i1, int i2,
-                   int j1, int j2, double valMin, double valMax, int extend, const double *affine)
+                   int j1, int j2, double valMin, double valMax, int extend, int filter, const double *affine)
 {
-   _giza_render (sizex, sizey, data,i1,i2,j1,j2,valMin,valMax,affine,2,extend,alpha);
+   _giza_render (sizex, sizey, data,i1,i2,j1,j2,valMin,valMax,affine,2,extend,filter,alpha);
 }
 
 /**
@@ -98,8 +107,8 @@ giza_render_alpha (int sizex, int sizey, const double* data, const double* alpha
  */
 void
 _giza_render (int sizex, int sizey, const double* data, int i1, int i2,
-	           int j1, int j2, double valMin, double valMax, const double *affine,
-              int transparent, int extend, const double* datalpha)
+                   int j1, int j2, double valMin, double valMax, const double *affine,
+              int transparent, int extend, int filter, const double* datalpha)
 {
   if (!_giza_check_device_ready ("giza_render"))
     return;
@@ -125,13 +134,16 @@ _giza_render (int sizex, int sizey, const double* data, int i1, int i2,
   cairo_extend_t cairoextendtype;
   _giza_get_extend(extend,&cairoextendtype);
 
+  cairo_filter_t cairofiltertype;
+  _giza_get_filter(filter,&cairofiltertype);
+
   /* apply the transformation */
   int oldCi;
   giza_get_colour_index (&oldCi);
   int oldTrans = _giza_get_trans ();
   _giza_set_trans (GIZA_TRANS_WORLD);
   cairo_matrix_init (&mat, affine[0], affine[1], affine[2], affine[3],
-		     affine[4], affine[5]);
+                   affine[4], affine[5]);
   cairo_transform (Dev[id].context, &mat);
 
   /* allocate data for the pixmap */
@@ -154,10 +166,10 @@ _giza_render (int sizex, int sizey, const double* data, int i1, int i2,
     for (j = j1; j <= j2; j++)
       {
         for (i = i1; i <= i2; i++)
-	  {
-	    _giza_colour_pixel_index_alpha (pixdata, pixnum, itf_idx(data[j*sizex + i], valMin, valMax, cimin, cimax), datalpha[j*sizex + i]);
-	    pixnum = pixnum + 1;
-	  }
+         {
+           _giza_colour_pixel_index_alpha (pixdata, pixnum, itf_idx(data[j*sizex + i], valMin, valMax, cimin, cimax), datalpha[j*sizex + i]);
+           pixnum = pixnum + 1;
+         }
       }
   } else if (transparent==1) {
     /* render each pixel, using transparent routine */
@@ -165,31 +177,35 @@ _giza_render (int sizex, int sizey, const double* data, int i1, int i2,
     for (j = j1; j <= j2; j++)
       {
         for (i = i1; i <= i2; i++)
-	  {
+         {
       idx = itf_idx(data[j*sizex + i], valMin, valMax, cimin, cimax);
-	    _giza_colour_pixel_index_alpha (pixdata, pixnum, idx, idx==cimin ? 0. : 1.);
-	    pixnum = pixnum + 1;
-	  }
+           _giza_colour_pixel_index_alpha (pixdata, pixnum, idx, idx==cimin ? 0. : 1.);
+           pixnum = pixnum + 1;
+         }
       }
   } else {
     /* render each pixel, usual routine */
     for (j = j1; j <= j2; j++)
       {
         for (i = i1; i <= i2; i++)
-	  {
-	    _giza_colour_pixel_index_alpha (pixdata, pixnum, itf_idx(data[j*sizex + i], valMin, valMax, cimin,cimax), 1.);
-	    pixnum = pixnum + 1;
-	  }
+         {
+           _giza_colour_pixel_index_alpha (pixdata, pixnum, itf_idx(data[j*sizex + i], valMin, valMax, cimin,cimax), 1.);
+           pixnum = pixnum + 1;
+         }
       }
   }
 
   /* create the cairo surface from the pixmap */
   pixmap = cairo_image_surface_create_for_data (pixdata, format,
-						width, height, stride);
+                                          width, height, stride);
 
   /* paint the pixmap to the primary surface */
   cairo_set_source_surface (Dev[id].context, pixmap, 0, 0);
   cairo_pattern_set_extend (cairo_get_source (Dev[id].context), cairoextendtype);
+
+  /* Set the interpolation filter */
+  cairo_pattern_set_filter (cairo_get_source(Dev[id].context), cairofiltertype);
+
   cairo_paint (Dev[id].context);
 
   /* clean up and restore settings */
@@ -210,10 +226,10 @@ _giza_render (int sizex, int sizey, const double* data, int i1, int i2,
  */
 void
 giza_render_float (int sizex, int sizey, const float* data, int i1,
-		  int i2, int j1, int j2, float valMin, float valMax,
-		  int extend, const float *affine)
+                int i2, int j1, int j2, float valMin, float valMax,
+                int extend, int filter, const float *affine)
 {
-  _giza_render_float (sizex,sizey,data,i1,i2,j1,j2,valMin,valMax,affine,0,extend,data);
+  _giza_render_float (sizex,sizey,data,i1,i2,j1,j2,valMin,valMax,affine,0,extend,filter,data);
 }
 
 /**
@@ -225,10 +241,10 @@ giza_render_float (int sizex, int sizey, const float* data, int i1,
  */
 void
 giza_render_transparent_float (int sizex, int sizey, const float* data, int i1,
-		  int i2, int j1, int j2, float valMin, float valMax,
-		  int extend, const float *affine)
+                int i2, int j1, int j2, float valMin, float valMax,
+                int extend, int filter, const float *affine)
 {
-  _giza_render_float (sizex,sizey,data,i1,i2,j1,j2,valMin,valMax,affine,1,extend,data);
+  _giza_render_float (sizex,sizey,data,i1,i2,j1,j2,valMin,valMax,affine,1,extend,filter,data);
 }
 
 /**
@@ -240,9 +256,9 @@ giza_render_transparent_float (int sizex, int sizey, const float* data, int i1,
  */
 void
 giza_render_alpha_float (int sizex, int sizey, const float* data, const float* alpha, int i1, int i2,
-	    int j1, int j2, float valMin, float valMax, int extend, const float *affine)
+           int j1, int j2, float valMin, float valMax, int extend, int filter, const float *affine)
 {
-   _giza_render_float (sizex, sizey, data,i1,i2,j1,j2,valMin,valMax,affine,2,extend,alpha);
+   _giza_render_float (sizex, sizey, data,i1,i2,j1,j2,valMin,valMax,affine,2,extend,filter,alpha);
 }
 /**
  *  _giza_render_float is the internal routine with the most general (and changeable) interface
@@ -250,8 +266,8 @@ giza_render_alpha_float (int sizex, int sizey, const float* data, const float* a
  */
 void
 _giza_render_float (int sizex, int sizey, const float* data, int i1,
-		    int i2, int j1, int j2, float valMin, float valMax,
-		    const float *affine, int transparent, int extend, const float* datalpha)
+                  int i2, int j1, int j2, float valMin, float valMax,
+                  const float *affine, int transparent, int extend, int filter, const float* datalpha)
 {
   if (!_giza_check_device_ready ("giza_render_float"))
     return;
@@ -259,13 +275,13 @@ _giza_render_float (int sizex, int sizey, const float* data, int i1,
   if (sizex < 1 || sizey < 1)
     {
       _giza_warning ("giza_render_float",
-		    "Invalid array size, skipping render.");
+                  "Invalid array size, skipping render.");
       return;
     }
   if (i1 < 0 || i2 < i1 || j1 < 0 || j2 < j1)
     {
       _giza_warning ("giza_render_float",
-		    "Invalid index range, skipping render.");
+                  "Invalid index range, skipping render.");
       return;
     }
 
@@ -279,13 +295,16 @@ _giza_render_float (int sizex, int sizey, const float* data, int i1,
   cairo_extend_t cairoextendtype;
   _giza_get_extend(extend,&cairoextendtype);
 
+  cairo_filter_t cairofiltertype;
+  _giza_get_filter(filter,&cairofiltertype);
+
   int oldCi;
   giza_get_colour_index (&oldCi);
   int oldTrans = _giza_get_trans ();
   _giza_set_trans (GIZA_TRANS_WORLD);
   cairo_matrix_init (&mat, (double) affine[0], (double) affine[1],
-		     (double) affine[2], (double) affine[3],
-		     (double) affine[4], (double) affine[5]);
+                   (double) affine[2], (double) affine[3],
+                   (double) affine[4], (double) affine[5]);
   cairo_transform (Dev[id].context, &mat);
 
 #if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 6, 0)
@@ -306,10 +325,10 @@ _giza_render_float (int sizex, int sizey, const float* data, int i1,
     for (j = j1; j <= j2; j++)
       {
         for (i = i1; i <= i2; i++)
-	  {
-	    _giza_colour_pixel_index_alpha (pixdata, pixnum, itf_idx(data[j*sizex + i], valMin, valMax, cimin, cimax), datalpha[j*sizex + i]);
-	    pixnum = pixnum + 1;
-	  }
+         {
+           _giza_colour_pixel_index_alpha (pixdata, pixnum, itf_idx(data[j*sizex + i], valMin, valMax, cimin, cimax), datalpha[j*sizex + i]);
+           pixnum = pixnum + 1;
+         }
       }
   } else if (transparent==1) {
     /* render each pixel, using transparent routine */
@@ -317,29 +336,31 @@ _giza_render_float (int sizex, int sizey, const float* data, int i1,
     for (j = j1; j <= j2; j++)
       {
         for (i = i1; i <= i2; i++)
-	  {
+         {
               idx = itf_idx(data[j*sizex + i], valMin, valMax, cimin, cimax);
               _giza_colour_pixel_index_alpha (pixdata, pixnum, idx, idx==cimin ? 0. : 1.);
               pixnum = pixnum + 1;
-	  }
+         }
       }
   } else {
     /* render each pixel, usual routine */
     for (j = j1; j <= j2; j++)
       {
         for (i = i1; i <= i2; i++)
-	  {
+         {
               _giza_colour_pixel_index_alpha (pixdata, pixnum, itf_idx(data[j*sizex + i], valMin, valMax, cimin, cimax), 1);
               pixnum = pixnum + 1;
-	  }
+         }
       }
   }
 
   pixmap = cairo_image_surface_create_for_data (pixdata, format,
-						width, height, stride);
+                                          width, height, stride);
 
   cairo_set_source_surface (Dev[id].context, pixmap, 0, 0);
   cairo_pattern_set_extend (cairo_get_source (Dev[id].context), cairoextendtype);
+  cairo_pattern_set_filter (cairo_get_source(Dev[id].context), cairofiltertype);
+
   cairo_paint (Dev[id].context);
 
   _giza_set_trans (oldTrans);
@@ -358,12 +379,12 @@ _giza_render_float (int sizex, int sizey, const float* data, int i1,
  */
 void
 giza_render_gray (int sizex, int sizey, const double* data, int i1,
-		  int i2, int j1, int j2, double valMin, double valMax,
-		  int extend, const double *affine)
+                int i2, int j1, int j2, double valMin, double valMax,
+                int extend, int filter, const double *affine)
 {
   giza_save_colour_table();
   giza_set_colour_table_gray ();
-  giza_render (sizex, sizey, data, i1, i2, j1, j2, valMin, valMax, extend, affine);
+  giza_render (sizex, sizey, data, i1, i2, j1, j2, valMin, valMax, extend, filter, affine);
   giza_restore_colour_table();
 }
 
@@ -376,12 +397,12 @@ giza_render_gray (int sizex, int sizey, const double* data, int i1,
  */
 void
 giza_render_gray_float (int sizex, int sizey, const float* data, int i1,
-		  int i2, int j1, int j2, float valMin, float valMax,
-		  int extend, const float *affine)
+                int i2, int j1, int j2, float valMin, float valMax,
+                int extend, int filter, const float *affine)
 {
   giza_save_colour_table();
   giza_set_colour_table_gray();
-  giza_render_float (sizex, sizey, data, i1, i2, j1, j2, valMin, valMax, extend, affine);
+  giza_render_float (sizex, sizey, data, i1, i2, j1, j2, valMin, valMax, extend, filter, affine);
   giza_restore_colour_table();
 }
 
@@ -484,12 +505,13 @@ _giza_colour_pixel_index_alpha (unsigned char *array, int pixNum, int ci, double
  *  -ymin        :- world coordinate corresponding to bottom of pixel array
  *  -ymax        :- world coordinate corresponding to top of pixel array
  *  -extend      :- Option for how to deal with image at edges (see giza_render)
+ *  -filter      :- Option for how to interpolate between pixels (see giza_render, since v1.5)
  *
  * See Also: giza_render, giza_draw_pixels_float
  */
 void
 giza_draw_pixels (int sizex, int sizey, const int* idata, int i1, int i2,
-	    int j1, int j2, double xmin, double xmax, double ymin, double ymax, int extend)
+           int j1, int j2, double xmin, double xmax, double ymin, double ymax, int extend, int filter)
 {
   if (!_giza_check_device_ready ("giza_render_pixels"))
     return;
@@ -513,6 +535,9 @@ giza_draw_pixels (int sizex, int sizey, const int* idata, int i1, int i2,
   cairo_extend_t cairoextendtype;
   _giza_get_extend(extend,&cairoextendtype);
 
+  cairo_filter_t cairofiltertype;
+  _giza_get_filter(filter,&cairofiltertype);
+
   /* apply the transformation */
   int oldCi;
   giza_get_colour_index (&oldCi);
@@ -522,7 +547,7 @@ giza_draw_pixels (int sizex, int sizey, const int* idata, int i1, int i2,
   double dxpix = (xmax - xmin)/((double) width);
   double dypix = (ymax - ymin)/((double) height);
   cairo_matrix_init (&mat, dxpix, 0.,0., dypix,
-		     xmin, ymin);
+                   xmin, ymin);
   cairo_transform (Dev[id].context, &mat);
 
   /* allocate data for the pixmap */
@@ -539,20 +564,21 @@ giza_draw_pixels (int sizex, int sizey, const int* idata, int i1, int i2,
   for (j = j1; j <= j2; j++)
     {
       for (i = i1; i <= i2; i++)
-	{
-	  int ci = idata[j*sizex+i];
-	  _giza_colour_pixel_index (pixdata, pixnum, ci);
-	  pixnum = pixnum + 1;
-	}
+       {
+         int ci = idata[j*sizex+i];
+         _giza_colour_pixel_index (pixdata, pixnum, ci);
+         pixnum = pixnum + 1;
+       }
     }
 
   /* create the cairo surface from the pixmap */
   pixmap = cairo_image_surface_create_for_data (pixdata, format,
-						width, height, stride);
+                                          width, height, stride);
 
   /* paint the pixmap to the primary surface */
   cairo_set_source_surface (Dev[id].context, pixmap, 0, 0);
   cairo_pattern_set_extend (cairo_get_source (Dev[id].context), cairoextendtype);
+  cairo_pattern_set_filter (cairo_get_source (Dev[id].context), cairofiltertype);
   cairo_paint (Dev[id].context);
 
   /* clean up and restore settings */
@@ -573,13 +599,13 @@ giza_draw_pixels (int sizex, int sizey, const int* idata, int i1, int i2,
  */
 void
 giza_draw_pixels_float (int sizex, int sizey, const int* idata, int i1, int i2,
-	    int j1, int j2, float xmin, float xmax, float ymin, float ymax, int extend)
+           int j1, int j2, float xmin, float xmax, float ymin, float ymax, int extend, int filter)
 {
   if (!_giza_check_device_ready ("giza_render_pixels_float"))
     return;
 
   giza_draw_pixels (sizex, sizey, idata, i1, i2,
-	    j1, j2, (double) xmin, (double) xmax, (double) ymin, (double) ymax, extend);
+           j1, j2, (double) xmin, (double) xmax, (double) ymin, (double) ymax, extend, filter);
 
 }
 
@@ -607,3 +633,37 @@ _giza_get_extend (int extend, cairo_extend_t *cairoextend)
     }
   return;
 }
+
+/**
+ * Internal routine to translate giza's integer value of filter to cairo's cairo_filter_t
+ */
+void
+_giza_get_filter (int filter, cairo_filter_t *cairofilter)
+{
+
+  switch (filter)
+    {
+    case GIZA_FILTER_FAST:
+       *cairofilter = CAIRO_FILTER_FAST;
+       break;
+    case GIZA_FILTER_GOOD:
+       *cairofilter = CAIRO_FILTER_GOOD;
+       break;
+    case GIZA_FILTER_BEST:
+       *cairofilter = CAIRO_FILTER_BEST;
+       break;
+    case GIZA_FILTER_NEAREST:
+       *cairofilter = CAIRO_FILTER_NEAREST;
+       break;
+    case GIZA_FILTER_BILINEAR:
+       *cairofilter = CAIRO_FILTER_BILINEAR;
+       break;
+    case GIZA_FILTER_GAUSSIAN:
+       *cairofilter = CAIRO_FILTER_GAUSSIAN;
+       break;
+    default:
+       *cairofilter = GIZA_FILTER_BEST;
+       break;
+    }
+  return;
+}
